[Lldb-commits] [lldb] r105713 - in /lldb/trunk/include/lldb: API/SBValue.h API/SBValueList.h Core/DataBufferMemoryMap.h Core/Value.h Expression/ClangFunction.h Interpreter/CommandCompletions.h Symbol/LineTable.h

Eli Friedman eli.friedman at gmail.com
Wed Jun 9 01:53:28 PDT 2010


Author: efriedma
Date: Wed Jun  9 03:53:28 2010
New Revision: 105713

URL: http://llvm.org/viewvc/llvm-project?rev=105713&view=rev
Log:
Misc warning/error fixes.


Modified:
    lldb/trunk/include/lldb/API/SBValue.h
    lldb/trunk/include/lldb/API/SBValueList.h
    lldb/trunk/include/lldb/Core/DataBufferMemoryMap.h
    lldb/trunk/include/lldb/Core/Value.h
    lldb/trunk/include/lldb/Expression/ClangFunction.h
    lldb/trunk/include/lldb/Interpreter/CommandCompletions.h
    lldb/trunk/include/lldb/Symbol/LineTable.h

Modified: lldb/trunk/include/lldb/API/SBValue.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/API/SBValue.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================
--- lldb/trunk/include/lldb/API/SBValue.h (original)
+++ lldb/trunk/include/lldb/API/SBValue.h Wed Jun  9 03:53:28 2010
@@ -12,10 +12,6 @@
 
 #include "lldb/API/SBDefines.h"
 
-class lldb_private::Variable;
-class lldb_private::ValueObject;
-class lldb_private::ExecutionContext;
-
 namespace lldb {
 
 class SBValue

Modified: lldb/trunk/include/lldb/API/SBValueList.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/API/SBValueList.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================
--- lldb/trunk/include/lldb/API/SBValueList.h (original)
+++ lldb/trunk/include/lldb/API/SBValueList.h Wed Jun  9 03:53:28 2010
@@ -12,8 +12,6 @@
 
 #include "lldb/API/SBDefines.h"
 
-class lldb_private::ValueObjectList;
-
 namespace lldb {
 
 class SBValueList

Modified: lldb/trunk/include/lldb/Core/DataBufferMemoryMap.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/DataBufferMemoryMap.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/Value.h (original)
+++ lldb/trunk/include/lldb/Core/Value.h Wed Jun  9 03:53:28 2010
@@ -36,7 +36,7 @@
         eValueTypeScalar,               // raw scalar value
         eValueTypeFileAddress,          // file address value
         eValueTypeLoadAddress,          // load address value
-        eValueTypeHostAddress,          // host address value (for memory in the process that is using liblldb)
+        eValueTypeHostAddress           // host address value (for memory in the process that is using liblldb)
     };
 
     enum ContextType                    // Type that describes Value::m_context

Modified: lldb/trunk/include/lldb/Expression/ClangFunction.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Expression/ClangFunction.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Expression/ClangFunction.h (original)
+++ lldb/trunk/include/lldb/Expression/ClangFunction.h Wed Jun  9 03:53:28 2010
@@ -16,7 +16,6 @@
 #include <list>
 // Other libraries and framework includes
 // Project includes
-#include "lldb/lldb.h"
 #include "lldb/Core/ClangForward.h"
 #include "lldb/Core/Address.h"
 #include "lldb/Core/Value.h"
@@ -39,7 +38,7 @@
 {
 public:
 
-    typedef enum ExecutionResults
+    enum ExecutionResults
     {
         eExecutionSetupError,
         eExecutionCompleted,
@@ -237,5 +236,5 @@
    bool m_JITted;
 };
 
-}; // Namespace lldb_private
+} // Namespace lldb_private
 #endif  // lldb_ClangFunction_h_

Modified: lldb/trunk/include/lldb/Interpreter/CommandCompletions.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Interpreter/CommandCompletions.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Interpreter/CommandCompletions.h (original)
+++ lldb/trunk/include/lldb/Interpreter/CommandCompletions.h Wed Jun  9 03:53:28 2010
@@ -236,5 +236,5 @@
 
 };
 
-}; // namespace lldb_private
+} // namespace lldb_private
 #endif  // lldb_CommandCompletions_h_

Modified: lldb/trunk/include/lldb/Symbol/LineTable.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Symbol/LineTable.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Symbol/LineTable.h (original)
+++ lldb/trunk/include/lldb/Symbol/LineTable.h Wed Jun  9 03:53:28 2010
@@ -264,7 +264,7 @@
             // rhs and lhs reversed on purpose below.
             SCALAR_COMPARE (rhs.is_terminal_entry, lhs.is_terminal_entry);
             SCALAR_COMPARE (lhs.file_idx, rhs.file_idx);
-            #undef SCALAR_COMPARE;
+            #undef SCALAR_COMPARE
             return 0;
         }
 
@@ -273,7 +273,7 @@
         {
         public:
             LessThanBinaryPredicate(LineTable *line_table);
-            bool operator() (const LineTable::Entry& a, const LineTable::Entry& a) const;
+            bool operator() (const LineTable::Entry&, const LineTable::Entry&) const;
         protected:
             LineTable *m_line_table;
         };





More information about the lldb-commits mailing list
--- lldb/trunk/include/lldb/Core/DataBufferMemoryMap.h (original)
+++ lldb/trunk/include/lldb/Core/DataBufferMemoryMap.h Wed Jun  9 03:53:28 2010
@@ -87,7 +87,7 @@
     /// Memory map all or part of a file.
     ///
     /// Memory map \a length bytes from \a file starting \a offset
     /// bytes into the file. If \a length is set to \c SIZE_T_MAX,
     /// then map as many bytes as possible.
     ///
     /// @param[in] file
@@ -99,7 +99,7 @@
     ///
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
     ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
     ///     as many bytes as possible.
     ///
     /// @return
@@ -108,14 +108,14 @@
     size_t
     MemoryMapFromFileSpec (const FileSpec* file,
                            off_t offset = 0,
-                           size_t length = SIZE_T_MAX);
+                           size_t length = SIZE_MAX);
 
     //------------------------------------------------------------------
     /// Memory map all or part of a file.
     ///
     /// Memory map \a length bytes from an opened file descriptor \a fd
     /// starting \a offset bytes into the file. If \a length is set to
     /// \c SIZE_T_MAX, then map as many bytes as possible.
     ///
     /// @param[in] fd
     ///     The posix file descriptor for an already opened file
@@ -127,14 +127,14 @@
     ///
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
     ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
     ///     as many bytes as possible.
     ///
     /// @return
     ///     The number of bytes mapped starting from the \a offset.
     //------------------------------------------------------------------
     size_t
-    MemoryMapFromFileDescriptor (int fd, off_t offset = 0, size_t length = SIZE_T_MAX);
+    MemoryMapFromFileDescriptor (int fd, off_t offset = 0, size_t length = SIZE_MAX);
 
 protected:
     //------------------------------------------------------------------
@@ -87,7 +87,7 @@
     ///
     /// Memory map \a length bytes from \a file starting \a offset
-    /// bytes into the file. If \a length is set to \c SIZE_T_MAX,
+    /// bytes into the file. If \a length is set to \c SIZE_MAX,
     /// then map as many bytes as possible.
     ///
@@ -99,7 +99,7 @@
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
-    ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
+    ///     bytes into the file. If \a length is \c SIZE_MAX, map
     ///     as many bytes as possible.
     ///
@@ -108,14 +108,14 @@
     /// Memory map \a length bytes from an opened file descriptor \a fd
     /// starting \a offset bytes into the file. If \a length is set to
-    /// \c SIZE_T_MAX, then map as many bytes as possible.
+    /// \c SIZE_MAX, then map as many bytes as possible.
     ///
     /// @param[in] fd
@@ -127,14 +127,14 @@
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
-    ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
+    ///     bytes into the file. If \a length is \c SIZE_MAX, map
     ///     as many bytes as possible.
     ///

Modified: lldb/trunk/include/lldb/Core/Value.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/Value.h?rev=105713&r1=105712&r2=105713&view=diff
==============================================================================